@@ -262,11 +262,11 @@ if __name__ == '__main__':
     #################################################################
     # Main program
     #################################################################
-    redfishclient_version = "redfish-client 0.4"
+    redfishclient_version = "redfish-client PBVER"
 
     # Parse and manage arguments
     try:
-        usagefp = '/usr/share/redfish-client' + "/redfish-client_usage.txt"
+        usagefp = 'PBSHAREPATH' + "/redfish-client_usage.txt"
         with open(usagefp) as usagefile:
             usage = usagefile.read()
             usagefile.close()
@@ -330,7 +330,7 @@ if __name__ == '__main__':
     # Load config
     config = configparser.ConfigParser(allow_no_value=True)
     logger.debug("Read configuration file")
-    configfile = '/etc/redfish-client.conf'
+    configfile = 'PBCONFFILE'
 
     if(arguments['--config']):
         configfile = arguments['--config']
